@@ -2,7 +2,7 @@
 Cucumber result to Jira Xray Test repository
 
 """
-__version__ = "0.5.1"
+__version__ = "0.5.2"
 
 
 import datetime
@@ -42,13 +42,13 @@ class CuJiraX:
 
     def set_testexecution(self, jira_key: str):
         try:
-            self.testexecution = Jirakey(jira_key)
+            self.testexecution = str(Jirakey(jira_key))
         except ValueError:
             self.testexecution = None
 
     def set_testplan(self, testplan_key: str):
         try:
-            self.result_info.testPlanKey = Jirakey(testplan_key)
+            self.result_info.testPlanKey = str(Jirakey(testplan_key))
         except ValueError:
             self.result_info.testPlanKey = None
 
